pub struct HpackEncoderConformanceCase {
pub id: String,
pub description: String,
pub initial_max_table_size: Option<usize>,
pub prelude_blocks: Vec<Vec<Header>>,
pub headers: Vec<Header>,
pub max_table_size: Option<usize>,
pub use_huffman: bool,
pub expected_identical: bool,
pub h2_golden_output: Option<Vec<u8>>,
pub h2_golden_table_size: Option<usize>,
}Expand description
Single HPACK encoder conformance test case.
Fields
id: Stringdescription: Stringinitial_max_table_size: Option<usize>Initial dynamic table size to construct the encoder/decoder with.
This is distinct from max_table_size: h2’s encoder tests can start
with a non-default table size without emitting an on-wire table-size
update first.
prelude_blocks: Vec<Vec<Header>>Header blocks encoded before headers to establish dynamic table state.
headers: Vec<Header>max_table_size: Option<usize>use_huffman: boolexpected_identical: boolh2_golden_output: Option<Vec<u8>>Golden bytes captured from hyperium/h2 for the final headers block.
h2_golden_table_size: Option<usize>Golden dynamic table byte size after the final h2 encode.