pub struct ReferenceSurfaceRegistry { /* private fields */ }Expand description
Queryable conformance reference-surface registry.
Implementations
Sourceimpl ReferenceSurfaceRegistry
impl ReferenceSurfaceRegistry
Sourcepub fn source_contract() -> Result<Self, ReferenceRegistryError>
pub fn source_contract() -> Result<Self, ReferenceRegistryError>
Load the embedded root registry contract.
Sourcepub fn from_json_str(json: &str) -> Result<Self, ReferenceRegistryError>
pub fn from_json_str(json: &str) -> Result<Self, ReferenceRegistryError>
Parse a registry contract JSON document.
Sourcepub fn from_rows(
rows: Vec<ReferenceSurfaceRow>,
) -> Result<Self, ReferenceRegistryError>
pub fn from_rows( rows: Vec<ReferenceSurfaceRow>, ) -> Result<Self, ReferenceRegistryError>
Build a registry from decoded rows.
Sourcepub fn surfaces(&self) -> impl Iterator<Item = &ReferenceSurfaceRow>
pub fn surfaces(&self) -> impl Iterator<Item = &ReferenceSurfaceRow>
Registered surfaces in deterministic surface-id order.
Sourcepub fn surface(
&self,
surface_id: &str,
) -> Result<&ReferenceSurfaceRow, ReferenceRegistryError>
pub fn surface( &self, surface_id: &str, ) -> Result<&ReferenceSurfaceRow, ReferenceRegistryError>
Fetch one row by surface id.
Sourcepub fn admit_runtime_verdict(
&self,
surface_id: &str,
verdict: RuntimeConformanceVerdict,
) -> Result<ReferenceVerdictAdmission, ReferenceRegistryError>
pub fn admit_runtime_verdict( &self, surface_id: &str, verdict: RuntimeConformanceVerdict, ) -> Result<ReferenceVerdictAdmission, ReferenceRegistryError>
Admit or reject a harness verdict for a registered surface.
Sourcepub fn guard_report(&self) -> ReferenceRegistryGuardReport
pub fn guard_report(&self) -> ReferenceRegistryGuardReport
Walk every registered reference surface and produce an e2e guard report.